# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tarot/tarot/chats.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17tarot/tarot/chats.proto\x12\x05tarot\"!\n\x11\x43reateChatRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\".\n\x12\x43reateChatResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t2J\n\x05\x43hats\x12\x41\n\nCreateChat\x12\x18.tarot.CreateChatRequest\x1a\x19.tarot.CreateChatResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tarot.tarot.chats_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_CREATECHATREQUEST']._serialized_start=34
  _globals['_CREATECHATREQUEST']._serialized_end=67
  _globals['_CREATECHATRESPONSE']._serialized_start=69
  _globals['_CREATECHATRESPONSE']._serialized_end=115
  _globals['_CHATS']._serialized_start=117
  _globals['_CHATS']._serialized_end=191
# @@protoc_insertion_point(module_scope)
